part of 'category_cubit.dart';

@immutable
abstract class CategoryState extends Equatable {
  @override
  List<Object> get props => [];
}

class CategoryInitial extends CategoryState {}

class CategoryLoading extends CategoryState {
  CategoryLoading();

  @override
  String toString() => 'CategoryLoading';
}

class CategoryFailure extends CategoryState {
  final String error;

  CategoryFailure(this.error);

  @override
  String toString() => 'ListServiceFailure { error: $error }';
}

class GetCategorySuccess extends CategoryState {
  @override
  String toString() => 'GetCategorySuccess';
}
